@@ -4,7 +4,8 @@ import os
 import time
 import re
 
-from omniversion.package_info import AvailableUpdates, PackageInfo, PackageInfosList, VersionsMatch, Vulnerabilities
+from omniversion.package_metadata import AvailableUpdates, PackageMetadata, PackagesMetadataList, VersionsMatch, \
+    Vulnerabilities
 from omniversion.file_info import FileInfo, FileInfosList
 
 from omniversion.pretty import pretty
@@ -16,7 +17,7 @@ class Data:
     files: FileInfosList
 
     def __init__(self, base_path: str | None = None, file_infos: FileInfosList | list[FileInfo] | None = None):
-        """Initialialize the root class"""
+        """Initialize the root class"""
         self.files = FileInfosList() if file_infos is None else FileInfosList(file_infos)
         if base_path is not None:
             load_data(base_path, self.files.append)
@@ -27,7 +28,7 @@ class Data:
 
     def hosts(self):
         """Deduplicated list of hosts for which files are present in the list"""
-        return list({file.host for file in self.files})
+        return sorted(list({file.host for file in self.files}))
 
     def items(
             self,
@@ -35,7 +36,7 @@ class Data:
             host: str | None = None,
             package_manager: str | None = None,
             package_name: str | list[str] | None = None,
-    ) -> list[PackageInfo]:
+    ) -> list[PackageMetadata]:
         """List all dependencies matching the given criteria"""
         def file_condition(file: FileInfo) -> bool:
             if file.data is None:
@@ -55,7 +56,7 @@ class Data:
             item for file_info in files_with_dependencies_data for item in file_info.data
         ]
 
-        def package_condition(package: PackageInfo) -> bool:
+        def package_condition(package: PackageMetadata) -> bool:
             if package_name is None:
                 return True
             if isinstance(package_name, list):
@@ -73,14 +74,14 @@ class Data:
         """List security vulnerabilities"""
         return Vulnerabilities(self.items("audit", host, package_manager, package_name))
 
-    def dependencies(
+    def list_packages(
             self,
             host: str | None = None,
             package_manager: str | None = None,
             package_name: str | list[str] | None = None,
     ):
         """List software packages"""
-        return PackageInfosList(self.items(["list", "version"], host, package_manager, package_name))
+        return PackagesMetadataList(self.items(["list", "version"], host, package_manager, package_name))
 
     def available_updates(
             self,
@@ -96,37 +97,41 @@ class Data:
     ):
         """Match versions of all installations of a particular package"""
         return VersionsMatch(
-            PackageInfosList(self.items(["list", "version"], package_name=package_name)),
+            PackagesMetadataList(self.items(["list", "version"], package_name=package_name)),
             package_name,
             display_name,
         )
 
     def add_local_config_value(
-            self, file_path, regex: str, package: str | None = None
+            self, file_path, regex: str, name: str | None = None
     ):
         """Add dependency meta data from a local file"""
         absolute_file_path = os.path.realpath(file_path)
         with open(absolute_file_path, encoding="utf8") as file:
-            matches = re.compile(regex).finditer(file.read())
-            for match in matches:
-                version = match.group("version")
-                package_name = package
-                if package_name is None:
-                    package_name = match.group("name")
-                package_info = PackageInfo(
-                    host="localhost",
-                    name=package_name,
-                    pm="local file",
-                    version=version,
-                )
-                file_name = os.path.basename(absolute_file_path)
-                file_info = FileInfo(
-                    PackageInfosList([package_info]),
-                    file_name,
-                    "localhost",
-                    "local file",
-                    "list",
-                    time.time(),
-                    file_path,
-                )
-                self.files.append(file_info)
+            try:
+                matches = re.compile(regex).finditer(file.read())
+                package_name = name
+                for match in matches:
+                    version = match.group("version")
+                    if package_name is None:
+                        package_name = match.group("name")
+                    package_metadata = PackageMetadata(
+                        host="localhost",
+                        name=package_name,
+                        package_manager="local file",
+                        current=version,
+                    )
+                    file_name = os.path.basename(absolute_file_path)
+                    file_info = FileInfo(
+                        PackagesMetadataList([package_metadata]),
+                        file_name,
+                        "localhost",
+                        "local file",
+                        "list",
+                        time.time(),
+                        file_path,
+                    )
+                    self.files.append(file_info)
+            except IndexError:
+                raise IndexError("Invalid regex. You need to provide a named group called `version` and either a name "
+                                 "parameter or a named group called `name`")
