@@ -2,7 +2,7 @@
 """List of imported files, including meta data"""
 from collections import UserList
 
-from ..helpers.group_by import group_by_host, group_by_verb
+from ..helpers import group_by_host, group_by_verb
 from ..pretty import pretty
 
 from .file_info import FileInfo
@@ -13,7 +13,7 @@ class FileInfosList(UserList[FileInfo]):
 
     def hosts(self):
         """Deduplicated list of hosts for which files are present in the list"""
-        return list({file.host for file in self})
+        return sorted(list({file.host for file in self}))
 
     def __str__(self):
         result = ""
